@@ -61,9 +61,10 @@ class EventReceiver(object):
                 "-",
             )
 
-            laccuna_logger.info("Processed request:", task_type)
+            print("Processed request:", task_type)
         except Exception as e:
             laccuna_logger.info(f"Event Receiver Exception is: {e}")
+            laccuna_logger.exception(e)
             response = {
                 "error": "Receiver exception",
                 "queue": self.queue_name,
@@ -80,7 +81,6 @@ class EventReceiver(object):
                 "end",
                 "Receiver exception",
             )
-            laccuna_logger.info("Receiver exception")
 
             ch.basic_publish(
                 exchange="",
